@@ -40,7 +40,7 @@ class Watcher(gobject.GObject):
 				
 	def _on_change(self, monitor, changed, event):
 		if event == gnomevfs.MONITOR_EVENT_CHANGED or event == gnomevfs.MONITOR_EVENT_CREATED:
-			self.emit('changed', gnomevfs.get_local_path_from_uri(changed))
+			gobject.idle_add(self.emit, 'changed', gnomevfs.get_local_path_from_uri(changed))
 
 class FileWatcher(Watcher):
 	def __init__(self):
@@ -51,7 +51,7 @@ class DirWatcher(Watcher):
 		Watcher.__init__(self)
 		self.monitor_type = gnomevfs.MONITOR_DIRECTORY
 
-if gtk.gtk_version < (2,8,0):
+if gtk.pygtk_version < (2,8,0):
 	gobject.type_register(Watcher)
 	gobject.type_register(FileWatcher)
 	gobject.type_register(DirWatcher)
